input - GooeyPy Docs

Documentation
Overview
gui

- app
- widget
- styleset
- effects

widgets

- label
- button
- input
- slider
- container
- box
- selectbox
- textblock
- image

- Input
- Input.font

# Input

Input([value, [max_length]]) - Input widget

Creates an HTML like input field.

### Arguments

value
  The initial value of the input (defaults to "").
max_length
  The maximum number of character that can be put into the Input.

## Input.font

Input.font -> pygame.Font

The font that this input is using.